{% extends "base.html" %}

{% block content %}

  <h3 data-i18n-key="page404_title" id="page404">Ops... Page not found!</h3>

  <p data-i18n-key="page_contents_title" class="page404-message">
    I'm sorry, but I can't find the page you are looking for.
  </p>

{% endblock %}
