wiki.languages = {};
/**
 * English
 * 
 */
wiki.languages.en = {
  "__code" : "en",
  "__description" : "English",
  "arrow_left_alt" : "Left arrow icon",
  "arrow_right_alt" : "Right arrow icon",
  "change_language" : "Change language",
  "close": "Close",
  "close_modal": "Close modal",
  "cookies_message" : "This wiki is not using cookies.",
  "contents" : "Contents",
  "docs_topics_title" : "Topics",
  "last_update" : "Last update",
  "left_arrow_icon" : "Left arrow icon",
  "menu_icon_alt" : "Navigation icon",
  "months" : {
    "01" : "January",
    "02" : "February",
    "03" : "March",
    "04" : "April",
    "05" : "May",
    "06" : "June",
    "07" : "July",
    "08" : "August",
    "09" : "September",
    "10" : "October",
    "11" : "November",
    "12" : "December"
  },
  "navigation_icon" : "Navigation icon",
  "next" : "Next",
  "organisation_logo" : "Organisation logo",
  "page404_message" : "I'm sorry, but I can't find the page you are looking for.",
  "page404_title" : "Ops... Page not found!",
  "page_contents_title" : "Contents",
  "pdf_version" : "Pdf version",
  "previous" : "Previous",
  "right_arrow_icon" : "Right arrow icon",
  "search": "Cerca",
  "search_icon" : "Search icon",
  "search_page_input" : "Find in documentation",
  "search_page_no_results" : "I am sorry, but I am not able to find what you are looking for.",
  "search_placeholder" : "Search...",
  "search_results" : "Search results",
  "search_within_the_wiki" : "Search within the wiki",
  "select_language" : "Select language",
  "support" : "Support",
  "topics" : "Topics",
  "use_keywords" : "Use keywords...",
  "useful_links" : "Useful links"
};
/**
 * Italiano
 * 
 */
wiki.languages.it = {
  "__code" : "it",
  "__description" : "Italiano",
  "arrow_left_alt": "Icona freccia sinistra",
  "arrow_right_alt": "Icona freccia destra",
  "change_language" : "Cambia lingua",
  "close": "Chiudi",
  "close_modal": "Chiudi modale",
  "cookies_message" : "Questo wiki non utilizza cookies.",
  "contents" : "Contenuti",
  "docs_topics_title": "Argomenti",
  "find_in_documentation": "Find in documentation",
  "last_update" : "Ultimo aggiornamento",
  "left_arrow_icon" : "Icona freccia sinistra",
  "menu_icon_alt": "Icona bottone menu", 
  "months" : {
    "01" : "Gennaio",
    "02" : "Febbraio",
    "03" : "Marzo",
    "04" : "Aprile",
    "05" : "Maggio",
    "06" : "Giugno",
    "07" : "Luglio",
    "08" : "Agosto",
    "09" : "Settembre",
    "10" : "Ottobre",
    "11" : "Novembre",
    "12" : "Dicembre"
  },
  "navigation_icon" : "Icona di navigazione",
  "next": "Argomento successivo",
  "organisation_logo" : "Logo organizzazione",
  "page404_message": "Mi dispiace, ma non riesco a trovare la pagina che stai cercando.",
  "page404_title": "Ops... Pagina non trovata!",
  "page_contents_title": "Contenuti",
  "pdf_version" : "Versione PDF",
  "previous": "Argomento precedente",
  "right_arrow_icon" : "Icona freccia destra",
  "search": "Cerca",
  "search_icon": "Icona bottone ricerca",
  "search_page_input": "Cerca nella documentazione",
  "search_page_no_results": "Mi dispiace, ma non riesco a trovare quello che stai cercando.",
  "search_placeholder": "Cerca...",
  "search_results" : "Risultati della ricerca",
  "search_within_the_wiki" : "Cerca nel wiki",
  "select_language" : "Seleziona la lingua",
  "support" : "Supporto",
  "topics" : "Argomenti",
  "use_keywords" : "Usa parole chiave...",
  "useful_links" : "Link utili"
};
